<?php
/**
 * Customizer default options
 *
 * @package Graduate_Pro
 * @since Graduate Pro 1.0
 * @return array An array of default values
 */

function graduate_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$graduate_pro_default_options = array(

		// Theme Options
		'theme_header_typography' 			=> 'default',
		'theme_typography' 					=> 'default',
		'loader_enable'         			=> false,
		'loader_icon'         				=> 'fa-spinner',
		'site_layout'         				=> 'wide',
		'sidebar_position'         			=> 'right-sidebar',
		'long_excerpt_length'           	=> 15,
		'read_more_text'		        	=> esc_html__( 'Read More', 'graduate-pro' ),
		'breadcrumb_enable'         		=> true,
		'animation_enable'         			=> true,
		'pagination_enable'         		=> true,
		'pagination_type'         			=> 'default',
		'copyright_text'                  	=> sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'graduate-pro' ), '[the-year]', '[site-link]' ) . ' &#124; ' . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . __( 'by', 'graduate-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        		=> true,
		'reset_options'      				=> false,
		'enable_frontpage_content' 			=> true,
		'author_box_enable'					=> true,
		'post_pagination_enable'			=> true,
		'theme_color'						=> 'blue',
		'primary_menu_search'				=> true,

		// Contact Page
		'contact_page_title'				=> esc_html__( 'Get In Touch', 'graduate-pro' ),
		'contact_page_description'			=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec nec turpis condimentum, interdum odio nec, porttitor sem. Ut ultrices ac ante sit amet pretium. Cras eget elit cursus, volutpat nibh vel, lacinia sapien.', 'graduate-pro' ),
		'contact_page_location'				=> esc_html__( 'Jawalakhel, Kathmandu, Nepal', 'graduate-pro' ),
		'contact_page_phone'				=> esc_html__( '+ 4875213654', 'graduate-pro' ),
		'contact_page_pobox'				=> esc_html__( 'SF54 5Sf', 'graduate-pro' ),
		'contact_page_email'				=> 'andyjones@gmail.com',
		'contact_page_social_count'			=> 4,
		'contact_page_map'					=> true,
		'contact_page_social_1'				=> 'facebook.com',
		'contact_page_social_2'				=> 'twitter.com',
		'contact_page_social_3'				=> 'youtube.com',
		'contact_page_social_4'				=> 'linkedin.com',

		// Top Bar
		'top_bar_enable'					=> 'static-frontpage',
		'top_bar_detail_phone'				=> esc_html__( '+00 0000000000', 'graduate-pro' ),
		'top_bar_detail_location'			=> esc_html__( 'Jackson Height, NY', 'graduate-pro' ),

		// Slider
		'slider_enable'						=> 'static-frontpage',
		'slider_content_effect'				=> 'fade',
		'enable_slider_controls'			=> true,
		'enable_slider_pager'				=> true,
		'enable_slider_dragable'			=> true,
		'slider_pause_on_hover'				=> true,
		'slider_autoplay'					=> true,
		'slider_transition_duration'		=> 1000,
		'slider_content_type'				=> 'demo',
		'no_of_slider'						=> 3,
		'search_text'						=> esc_html__( 'Search For', 'graduate-pro' ),

		// About Content
		'about_content_enable'				=> 'static-frontpage',
		'about_content_type'				=> 'demo',
		'about_content_excerpt_length'		=> 25,

		// Information Section
		'information_section_enable'		=> 'static-frontpage',
		'information_section_content_type'	=> 'demo',
		'information_section_column'		=> 3,

		// Trending Courses
		'trending_courses_enable'			=> 'static-frontpage',
		'trending_courses_content_type'		=> 'demo',
		'trending_courses_display_title'	=> true,
		'trending_courses_column'			=> 4,
		'trending_courses_count'			=> 3,
		'trending_courses_title'			=> esc_html__( 'Trending Courses', 'graduate-pro' ),
		'trending_courses_description'		=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Donec a neque interdum diam dapibus tinci dunt. In euismod risus nec.', 'graduate-pro' ),

		// Top Destination
		'top_destination_enable'			=> 'static-frontpage',
		'top_destination_display_title'		=> true,
		'top_destination_content_type'		=> 'demo',
		'top_destination_count'				=> 6,
		'top_destination_title'				=> esc_html__( 'Top Destinations', 'graduate-pro' ),
		'top_destination_description'		=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec a neque interdum diam dapibus tincidunt. In euismod risus nec pellentesque egestas.', 'graduate-pro' ),

		// Team Section
		'team_section_enable'				=> 'static-frontpage',
		'team_section_content_type'			=> 'demo',
		'team_section_count'				=> 15,

		// Map Section
		'map_section_enable'				=> 'disabled',
		'map_section_title'					=> esc_html__( 'Universities Overview', 'graduate-pro' ),
		'map_section_content_type'			=> 'shortcode',

		// Testimonial Section
		'testimonial_enable'				=> 'static-frontpage',
		'testimonial_title'					=> esc_html__( 'Testimonial', 'graduate-pro' ),
		'testimonial_content_type'			=> 'demo',
		'testimonial_count'					=> 5,

		// Client Section
		'client_section_enable'				=> 'static-frontpage',
		'client_section_content_type'		=> 'demo',
		'client_section_count'				=> 6,
		'client_section_controller'			=> false,
		'client_section_pager'				=> false,
		'client_section_draggable'			=> true,
		'client_section_infinite_loop'		=> false,
		'client_section_autoplay'			=> true,
		'client_section_visible_slides'		=> 6,

		// Featured Content
		'featured_content_enable'			=> 'static-frontpage',
		'featured_content_type'				=> 'demo',

		// Counter
		'counter_content_enable'			=> 'static-frontpage',
		'counter_content_type'				=> 'demo',
		'counter_background'				=> get_template_directory_uri() . '/assets/uploads/counter-section-bg.jpg',
		'counter_heading_title'				=> esc_html__( 'We help you to grow!', 'graduate-pro' ),
		'counter_heading_description'		=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut rutrum vel eros at facilisis. Nunc a vulputate elit, et consequat nunc. Ut tellus lectus, efficitur et ultricies vel, fringilla sit amet ligula.', 'graduate-pro' ),
		'counter_btn_label'					=> esc_html__( 'Join Us', 'graduate-pro' ),
		'counter_btn_url'					=> '#',
		'counter_box_enable'				=> true,
		'counter_box_count_1'				=> 110,
		'counter_box_count_2'				=> 95,
		'counter_box_count_3'				=> 650,
		'counter_box_count_4'				=> 25,
		'counter_label_1'					=> esc_html__( 'Courses Available', 'graduate-pro' ),
		'counter_label_2'					=> esc_html__( 'Experienced Professors', 'graduate-pro' ),
		'counter_label_3'					=> esc_html__( 'Student Enrolled', 'graduate-pro' ),
		'counter_label_4'					=> esc_html__( 'Trophy Won', 'graduate-pro' ),

		// News & Events
		'news_events_enable'				=> 'static-frontpage',
		'news_events_display_title'			=> true,
		'news_events_content_type'			=> 'demo',
		'news_events_column'				=> 4,
		'news_events_count'					=> 3,
		'news_events_title'					=> esc_html__( 'News & Events', 'graduate-pro' ),
		'news_events_description'			=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Donec a neque interdum diam dapibus tin cidunt.', 'graduate-pro' ),

		// Social Section
		'social_section_enable'				=> 'static-frontpage',
		'social_section_content_type'		=> 'demo',
		'social_section_title'				=> esc_html__( 'Let&#39;s Get Social', 'graduate-pro' ),
		'social_section_count'				=> 4,

		

	);

	$output = apply_filters( 'graduate_pro_default_theme_options', $graduate_pro_default_options );
	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}