<?php
/**
* Featured Content options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add Featured Content enable section
$wp_customize->add_section( 'graduate_pro_featured_content', array(
	'title'             => esc_html__( 'Featured Content','graduate-pro' ),
	'description'		=> esc_html__( 'Featured Content Options', 'graduate-pro' ),
	'panel'             => 'graduate_pro_section_options_panel'
) );

// Add Featured Content enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[featured_content_enable]', array(
	'default'           => $options['featured_content_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[featured_content_enable]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_featured_content',
	'type'              => 'select',
	'choices'           => graduate_pro_enable_disable_options()
) );

// Add Featured Content type setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[featured_content_type]', array(
	'default'           => $options['featured_content_type'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[featured_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_featured_content',
	'type'            	=> 'select',
	'active_callback' 	=> 'graduate_pro_is_featured_content_active',
	'choices'         	=> graduate_pro_information_section_content_type()
) );

// Category Content Type
$wp_customize->add_setting(  'graduate_pro_theme_options[featured_content_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new graduate_Pro_Dropdown_Category_Control ( $wp_customize,'graduate_pro_theme_options[featured_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'graduate-pro' ),
	'section'           => 'graduate_pro_featured_content',
	'type'              => 'dropdown-category',
	'active_callback'	=> 'graduate_pro_is_featured_content_category_active'
) ) );

for( $i = 1; $i <= 2; $i++ ) {

	// page content type setting and control.
	$wp_customize->add_setting( 'graduate_pro_theme_options[featured_content_page_'. $i .']', array(
		'sanitize_callback' => 'graduate_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[featured_content_page_'. $i .']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'graduate-pro' ), $i ),
		'section'         	=> 'graduate_pro_featured_content',
		'type'            	=> 'dropdown-pages',
		'active_callback' 	=> 'graduate_pro_is_featured_content_page_active',
	) );

	// post content type setting and control.
	$wp_customize->add_setting( 'graduate_pro_theme_options[featured_content_post_'. $i .']', array(
		'sanitize_callback' => 'graduate_pro_sanitize_number_range',
		'validate_callback' => 'graduate_pro_validate_post_id'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[featured_content_post_'. $i .']', array(
		'label'           	=> sprintf( esc_html__( 'Select Post %d', 'graduate-pro' ), $i ),
		'section'         	=> 'graduate_pro_featured_content',
		'type'            	=> 'number',
		'active_callback' 	=> 'graduate_pro_is_featured_content_post_active',
		'input_attrs'		=> array(
				'style'	=> 'width:100px'
			)
	) );

	// Category List content type hr setting and control
	$wp_customize->add_setting( 'graduate_pro_theme_options[featured_content_hr_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new graduate_Pro_Customize_Horizontal_Line( $wp_customize, 'graduate_pro_theme_options[featured_content_hr_'.$i.']',
		array(
			'section'         => 'graduate_pro_featured_content',
			'active_callback' => 'graduate_pro_is_featured_content_cat_list_active',
			'type'			  => 'hr'
	) ) );

	// Category List content type image setting and control
	$wp_customize->add_setting( 'graduate_pro_theme_options[featured_content_image_'. $i .']',
	  array(
	    'sanitize_callback' 	=> 'graduate_pro_sanitize_image',
	  )
	);
	$wp_customize->add_control(
	  new WP_Customize_Image_Control( $wp_customize, 'graduate_pro_theme_options[featured_content_image_'. $i .']',
	    array(
	    	'label'       		=> sprintf( esc_html__( 'Select Image %d', 'graduate-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'graduate-pro' ), 600, 200 ),
			'section'     		=> 'graduate_pro_featured_content',
			'active_callback'	=> 'graduate_pro_is_featured_content_cat_list_active',
	    )
	  )
	);

	// Category List Content Type
	$wp_customize->add_setting(  'graduate_pro_theme_options[featured_content_cat_list_'. $i .']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new graduate_Pro_Dropdown_Category_Control ( $wp_customize,'graduate_pro_theme_options[featured_content_cat_list_'. $i .']', array(
		'label'             => sprintf( esc_html__( 'Select Category %d', 'graduate-pro' ), $i ),
		'section'           => 'graduate_pro_featured_content',
		'type'              => 'dropdown-category',
		'active_callback'	=> 'graduate_pro_is_featured_content_cat_list_active'
	) ) );

}