<?php
/**
* Information Section options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add Information Section enable section
$wp_customize->add_section( 'graduate_pro_information_section', array(
	'title'             => esc_html__( 'Information Section','graduate-pro' ),
	'description'       => esc_html__( 'Information Section Options.', 'graduate-pro' ),
	'panel'             => 'graduate_pro_section_options_panel'
) );

// Add Information Section enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[information_section_enable]', array(
	'default'           => $options['information_section_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[information_section_enable]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_information_section',
	'type'              => 'select',
	'choices'           => graduate_pro_enable_disable_options()
) );

// Add Information Section type setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[information_section_content_type]', array(
	'default'           => $options['information_section_content_type'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[information_section_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_information_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'graduate_pro_is_information_section_active',
	'choices'         	=> graduate_pro_information_section_content_type()
) );

// Column option
$wp_customize->add_setting( 'graduate_pro_theme_options[information_section_column]', array(
	'default'           => $options['information_section_column'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[information_section_column]', array(
	'label'           	=> esc_html__( 'Select Column layout', 'graduate-pro' ),
	'description'       => esc_html__( 'No. of content is propotional to No. of column.', 'graduate-pro' ),
	'section'        	=> 'graduate_pro_information_section',
	'active_callback' 	=> 'graduate_pro_is_information_section_is_not_demo',
	'type'				=> 'select',
	'choices'         	=> graduate_pro_information_section_column()
) );

for ( $i = 1; $i <= $options['information_section_column']; $i++ ) {

	// Page Content Type
	$wp_customize->add_setting( 'graduate_pro_theme_options[information_section_page_'. $i .']', array(
		'sanitize_callback' => 'graduate_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[information_section_page_'. $i .']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'graduate-pro' ), $i ),
		'section'        	=> 'graduate_pro_information_section',
		'active_callback' 	=> 'graduate_pro_is_information_section_page_active',
		'type'				=> 'dropdown-pages'
	) );

	// Post Content Type
	$wp_customize->add_setting( 'graduate_pro_theme_options[information_section_post_'. $i .']', array(
		'sanitize_callback' => 'graduate_pro_sanitize_number_range',
		'validate_callback' => 'graduate_pro_validate_post_id'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[information_section_post_'. $i .']', array(
		'label'           	=> sprintf( esc_html__( 'Input Post ID %d', 'graduate-pro' ), $i ),
		'section'         	=> 'graduate_pro_information_section',
		'active_callback' 	=> 'graduate_pro_is_information_section_post_active',
		'type'				=> 'number',
		'input_attrs'     	=> array(
			'min'	=> 1,
			'style' => 'width:100px'
			)
	) );

	// Category List hr setting and control
	$wp_customize->add_setting( 'graduate_pro_theme_options[information_section_hr_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new graduate_Pro_Customize_Horizontal_Line( $wp_customize, 'graduate_pro_theme_options[information_section_hr_'.$i.']',
		array(
			'section'         => 'graduate_pro_information_section',
			'active_callback' => 'graduate_pro_is_information_section_cat_list_active',
			'type'			  => 'hr'
	) ) );

	// Category List Content Type
	$wp_customize->add_setting(  'graduate_pro_theme_options[information_section_category_list_'. $i .']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new graduate_Pro_Dropdown_Category_Control ( $wp_customize,'graduate_pro_theme_options[information_section_category_list_'. $i .']', array(
		'label'             => sprintf( esc_html__( 'Select Category %d', 'graduate-pro' ), $i ),
		'section'           => 'graduate_pro_information_section',
		'type'              => 'dropdown-category',
		'active_callback'	=> 'graduate_pro_is_information_section_cat_list_active'
	) ) );

	// Category List select image
	$wp_customize->add_setting( 'graduate_pro_theme_options[information_section_image_'. $i .']',
	  array(
	    'sanitize_callback' 	=> 'graduate_pro_sanitize_image',
	  )
	);
	$wp_customize->add_control(
	  new WP_Customize_Image_Control( $wp_customize, 'graduate_pro_theme_options[information_section_image_'. $i .']',
	    array(
	    	'label'       		=> sprintf( esc_html__( 'Select Image %d', 'graduate-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx.', 'graduate-pro' ), 400, 600 ),
			'section'     		=> 'graduate_pro_information_section',
			'settings'    		=> 'graduate_pro_theme_options[information_section_image_'. $i .']',
			'active_callback'	=> 'graduate_pro_is_information_section_cat_list_active',
	    )
	  )
	);

	// alt text for image
	$wp_customize->add_setting( 'graduate_pro_theme_options[information_section_image_alt_'. $i .']',
	  array(
	    'sanitize_callback' 	=> 'sanitize_text_field',
	  )
	);
	$wp_customize->add_control( 'graduate_pro_theme_options[information_section_image_alt_'. $i .']',
    array(
		'description'			=> esc_html__( 'Alternative text for image', 'graduate-pro' ),
		'section'     			=> 'graduate_pro_information_section',
		'settings'    			=> 'graduate_pro_theme_options[information_section_image_alt_'. $i .']',
		'type'		  			=> 'text',
		'active_callback'		=> 'graduate_pro_is_information_section_cat_list_active',
      )
	);

}

// Category Content Type
$wp_customize->add_setting(  'graduate_pro_theme_options[information_section_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new graduate_Pro_Dropdown_Category_Control ( $wp_customize,'graduate_pro_theme_options[information_section_category]', array(
	'label'             => esc_html__( 'Select Category', 'graduate-pro' ),
	'section'           => 'graduate_pro_information_section',
	'type'              => 'dropdown-category',
	'active_callback'	=> 'graduate_pro_is_information_section_category_active'
) ) );