<?php
/**
* Map Section options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add Map Section enable section
$wp_customize->add_section( 'graduate_pro_map_section', array(
	'title'             => esc_html__( 'Map Section','graduate-pro' ),
	'description'		=> esc_html__( 'Map Section Options', 'graduate-pro' ),
	'panel'             => 'graduate_pro_section_options_panel'
) );

// Add Map Section enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[map_section_enable]', array(
	'default'           => $options['map_section_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[map_section_enable]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_map_section',
	'type'              => 'select',
	'choices'           => graduate_pro_enable_disable_options()
) );

// Add Map Section title
$wp_customize->add_setting( 'graduate_pro_theme_options[map_section_title]', array(
	'default'           => $options['map_section_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[map_section_title]', array(
	'label'             => esc_html__( 'Title', 'graduate-pro' ),
	'section'           => 'graduate_pro_map_section',
	'type'              => 'text',
	'active_callback'   => 'graduate_pro_is_map_section_active'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'graduate_pro_theme_options[map_section_title]', array(
		'selector'            => '#map-section .entry-header h2.entry-title',
		'settings'            => 'graduate_pro_theme_options[map_section_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'graduate_pro_partial_map_section_title',
    ) );
}

// Add Map Section content type setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[map_section_content_type]', array(
	'default'			=> $options['map_section_content_type'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[map_section_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'graduate-pro' ),
	'section'           => 'graduate_pro_map_section',
	'type'              => 'select',
	'choices'           => graduate_pro_map_section_type(),
	'active_callback'   => 'graduate_pro_is_map_section_active'
) );

// Add Map Section title
$wp_customize->add_setting( 'graduate_pro_theme_options[map_section_shortcode]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[map_section_shortcode]', array(
	'label'             => esc_html__( 'Input Map Shortcode', 'graduate-pro' ),
	'section'           => 'graduate_pro_map_section',
	'type'              => 'text',
	'active_callback'   => 'graduate_pro_is_map_section_content_shortcode'
) );

// Add Map Section title
$wp_customize->add_setting( 'graduate_pro_theme_options[map_section_embed]', array(
	'sanitize_callback' => 'graduate_pro_santize_iframe_map'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[map_section_embed]', array(
	'label'             => esc_html__( 'Input Map Embed Code', 'graduate-pro' ),
	'section'           => 'graduate_pro_map_section',
	'type'              => 'textarea',
	'active_callback'   => 'graduate_pro_is_map_section_content_embed'
) );