<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Graduate_Pro
 * @since Graduate Pro 1.0
 */
if ( ! function_exists( 'graduate_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Graduate Pro 1.0
    */
    function graduate_pro_add_slider_section() {

    // Check if slider is enabled on frontpage
    $slider_enable = apply_filters( 'graduate_pro_section_status', true, 'slider_enable' );
    if ( true !== $slider_enable ) {
      return false;
    }

    // Get slider section details
    $section_details = array();
    $section_details = apply_filters( 'graduate_pro_filter_slider_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render slider section now.
    graduate_pro_render_slider_section( $section_details );
    }
endif;
add_action( 'graduate_pro_primary_content', 'graduate_pro_add_slider_section', 10 );


if ( ! function_exists( 'graduate_pro_get_slider_section_details' ) ) :
  /**
   * Slider section details.
   *
   * @since Graduate Pro 1.0
   * @param array $input Slider section details.
   */
  function graduate_pro_get_slider_section_details( $input ) {
    $options = graduate_pro_get_theme_options();

    // Slider type
    $slider_content_type  = $options['slider_content_type'];

    $content = array();
    switch ( $slider_content_type ) {
        case 'demo':
            for ( $i = 1; $i <= 2; $i++ ) {
                $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/slider-0'.$i.'.jpg';
                $content[$i]['url']          = '#';
                $content[$i]['title']        = esc_html__( 'Internships Around the World', 'graduate-pro' );
                $content[$i]['excerpt']      = esc_html__( 'Get Work Experience While Studying Abroad...', 'graduate-pro' );
                $content[$i]['alt']          = esc_attr__( 'Slider Image', 'graduate-pro' );
            }
        break;

        case 'page':
            $ids = array();

            for ( $i = 1; $i <= $options['no_of_slider']; $i++ ) {
                $id = null;
                if ( isset( $options[ 'slider_content_page_'.$i ] ) ) {
                    $id = $options[ 'slider_content_page_'.$i ];
                }
                if ( ! empty( $id ) ) {
                    $ids[] = absint( $id );
                }
            }

            // Bail if no valid pages are selected.
            if ( empty( $ids ) ) {
                return $input;
            }

            $args = array(
                'no_found_rows'  => true,
                'orderby'        => 'post__in',
                'post_type'      => 'page',
                'post__in'       => $ids,
            );
        break;

        case 'post':
            $ids = array();

            for ( $i = 1; $i <= $options['no_of_slider']; $i++ ) {
                $id = null;
                if ( isset( $options[ 'slider_content_post_'.$i ] ) ) {
                    $id = $options[ 'slider_content_post_'.$i ];
                }
                if ( ! empty( $id ) ) {
                    $ids[] = absint( $id );
                }
            }

            // Bail if no valid pages are selected.
            if ( empty( $ids ) ) {
                return $input;
            }

            $args = array(
                'no_found_rows'  => true,
                'orderby'        => 'post__in',
                'post_type'      => 'post',
                'post__in'       => $ids,
            );
        break;

        case 'category':
            $cat_id = '';
            if ( ! empty( $options['slider_content_category'] ) ) {
                $cat_id = $options['slider_content_category'];
            }

            // Bail if no valid pages are selected.
            if ( empty( $cat_id ) ) {
                return $input;
            }else{
                $cat_id = absint( $cat_id );
            }

            $args = array(
                'no_found_rows'  => true,
                'cat'            => $cat_id,
                'post_type'      => 'post',
                'posts_per_page'  => absint( $options['no_of_slider'] ),
                'orderby'        => 'ASC',
            );
        break;

        default:
        break;
    }

    if ( 'demo' != $slider_content_type ) {
        // Fetch posts.
        $posts = get_posts( $args );

        if ( ! empty( $posts ) ) {
            $i = 1;
            foreach ( $posts as $key => $post ) {

                $page_id = $post->ID;
                $img_array = null;
                if ( has_post_thumbnail( $page_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-1200x500.jpg';
                }

                if ( isset( $img_array ) ) {
                    $content[$i]['img_array'] = $img_array;
                }

                $content[$i]['url']      = get_permalink( $page_id );
                $content[$i]['title']    = get_the_title( $page_id );
                $content[$i]['excerpt']  = graduate_pro_trim_content( 6, $post  );
                $content[$i]['alt']      = get_the_title( $page_id );

                $i++;
            }
            wp_reset_postdata();
        }
    }

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// Slider section content details.
add_filter( 'graduate_pro_filter_slider_section_details', 'graduate_pro_get_slider_section_details' );


if ( ! function_exists( 'graduate_pro_render_slider_section' ) ) :
    /**
    * Start slider section
    *
    * @return string Slider content
    * @since Graduate Pro 1.0
    *
    */
    function graduate_pro_render_slider_section( $content_details = array() ) {
        $options          = graduate_pro_get_theme_options();
        $slider_effect    = ( $options['slider_content_effect'] == 'fade' ) ? 'linear' : $options['slider_content_effect'];
        $slider_fade      = ( $options['slider_content_effect'] == 'fade' ) ? 'true' : 'false';
        $slider_control   = ( $options['enable_slider_controls'] == true ) ? 'true' : 'false';
        $slider_pager     = ( $options['enable_slider_pager'] == true ) ? 'true' : 'false';
        $slider_dragable  = ( $options['enable_slider_dragable'] == true ) ? 'true' : 'false';
        $slider_pause     = ( $options['slider_pause_on_hover'] == true ) ? 'true' : 'false';
        $slider_autoplay  = ( $options['slider_autoplay'] == true ) ? 'true' : 'false';
        $slider_speed     = ( $options['slider_transition_duration'] ) ? $options['slider_transition_duration'] : 1000;

        if ( empty( $content_details ) ) {
          return;
        } ?>

        <section id="main-slider" data-effect="<?php echo esc_attr( $slider_effect ); ?>" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": <?php echo esc_attr( $slider_speed ); ?>, "dots": <?php echo esc_attr( $slider_pager ); ?>, "arrows":<?php echo esc_attr( $slider_control ); ?>, "autoplay": <?php echo esc_attr( $slider_autoplay ); ?>, "fade": <?php echo esc_attr( $slider_fade ); ?>, "draggable": <?php echo esc_attr( $slider_dragable ); ?>, "pauseOnHover": <?php echo esc_attr( $slider_pause ); ?> }'>
            <?php 
            $i = 1;
            foreach ( $content_details as $content_detail ) : ?>
                <div class="slider-item <?php echo ( $i == 1 ) ? 'display-block' : 'display-none'; ?>" style="background-image: url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>')">
                    <div class="main-slider-contents wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.3s">
                        <div class="container">
                            <h2 class="title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="color-white"><?php echo esc_html( $content_detail['title'] ); ?></a></h2>  
                            <p class="desc"><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                        </div><!-- end .container -->
                    </div><!-- end .main-slider-contents -->
                </div><!-- end .slider-item -->
            <?php
            $i++;
            endforeach; ?>
        </section><!-- end #main-slider -->

<?php 
    }
endif;